@@ -109,7 +109,7 @@ class LongHandlerEN(Operation):
         self.is_right_quota = condition.IsRightQuotaEn(symbols)
         self.not_in_white_list = condition.NotInWhitelistDotEn()
         self.is_next_with_space = condition.IsNextWithSpace(symbols)
-        self.is_next_with_quota = condition.IsNextWithEndQuota(symbols)
+        #self.is_next_with_quota = condition.IsNextWithEndQuota(symbols)
         self.min_sentence_length = min_sentence_length
         self.space = self.symbols['all_symbols']
         self.blank = re.compile('\r')
